# ApiNyaEr

A Python package that compiles and fetches data from multiple APIs into a unified format.

## Features  
- AI-powered capabilities  
- Auto-generated images using Flux.1 Schennel  
- And more!  

📖 **See the full list of features in the [Documentation](#documentation)**

## Installation

**You can install this package using pip:**

```bash
pip3 install ApiNyaEr
```

**Or install directly from GitHub:**

```bash
pip install git+https://github.com/ErBots/ApiNyaEr
```
## Usage

Don't forget to Import the package
```bash
from ApiNyaEr import apinya
```
Then call the function
```py
result = await apinya.erai("hellow, can u understand my hearth?")
print(result)
```
## Documentation
  - [Read The Docs](https://docs-apinyaer.rtfd.io)

## Contribute  
If you find a bug, please [open an issue](https://github.com/ErBots/ApiNyaEr/issues).  
You can also contribute by submitting a pull request!

# Migrating Project
  - [Rest Apis](https://er-api.biz.id)
  - [@er-npm/scraper](https://www.npmjs.com/package/@er-npm/scraper)

> This Project is Licensed under [GNU General Public License](https://github.com/ErBots/ApiNyaEr/blob/Er/LICENSE)